@@ -187,10 +187,13 @@ stopifnot(identical(SimInf:::valid_SimInf_model_object(m),
                     "The number of nodes in 'u0' and 'ldata' must match."))
 
 ## Check valid_SimInf_model_object with invalid gdata.
-m <- SIR(u0 = data.frame(S = 10, I = 0, R = 0),
-         tspan = 1:10, beta = 0.1, gamma = 0.1)
+m <- SISe(u0 = data.frame(S = 10, I = 0), tspan = 1:10, phi = 0,
+          upsilon = 0.1, gamma = 0.1, alpha = 1.0, beta_t1 = 0.1,
+          beta_t2 = 0.1, beta_t3 = 0.1, beta_t4 = 0.1, end_t1  = 91,
+          end_t2  = 182, end_t3  = 273, end_t4  = 365, epsilon = 0.1)
 m@gdata <- as.integer(m@gdata)
-names(m@gdata) <- c("beta", "gamma")
+names(m@gdata) <- c("upsilon", "gamma", "alpha", "beta_t1",
+                    "beta_t2", "beta_t3", "beta_t4", "epsilon")
 stopifnot(identical(SimInf:::valid_SimInf_model_object(m),
                     "'gdata' must be a double vector."))
 
@@ -202,7 +205,7 @@ res <- assertError(SimInf_model(G     = G,
                                 tspan = c(1, 2),
                                 u0    = u0,
                                 v0    = 1))
-check_error(res, "v0 must be a numeric matrix.")
+check_error(res, "'v0' must be a double matrix.")
 res <- SimInf_model(G     = G,
                     S     = S,
                     U     = U,
@@ -287,7 +290,7 @@ res <- assertError(SimInf_model(G     = G,
                                 ldata = matrix(rep(0, Nn), nrow = 1),
                                 tspan = as.numeric(1:10),
                                 u0    = u0_double))
-check_error(res, "u0 must be an integer matrix.")
+check_error(res, "'u0' must be an integer matrix.")
 
 ## Change u0 to vector. Should raise an error.
 res <- assertError(SimInf_model(G     = G,
@@ -296,7 +299,7 @@ res <- assertError(SimInf_model(G     = G,
                                 ldata = matrix(rep(0, Nn), nrow = 1),
                                 tspan = as.numeric(1:10),
                                 u0    = as.numeric(u0)))
-check_error(res, "u0 must be an integer matrix.")
+check_error(res, "'u0' must be an integer matrix.")
 
 ## Check S
 res <- assertError(new("SimInf_model",
@@ -406,7 +409,7 @@ u0 <- data.frame(S_1 = c(0, 1, 2, 3, 4, 5),
 
 ## 'u0' is NULL
 res <- assertError(SimInf_model())
-check_error(res, "'u0' is NULL.")
+check_error(res, "'u0' must be an integer matrix.")
 
 ## Check first lines of show method without events
 model <- SISe(u0      = data.frame(S = 99, I = 1),
@@ -493,11 +496,11 @@ stopifnot(identical(
     show_observed[22:28],
     c("Local data",
       "----------",
-      "        Min. 1st Qu. Median Mean 3rd Qu. Max.",
-      " end_t1   91      91     91   91      91   91",
-      " end_t2  182     182    182  182     182  182",
-      " end_t3  273     273    273  273     273  273",
-      " end_t4  365     365    365  365     365  365")))
+      " Parameter Value",
+      " end_t1     91  ",
+      " end_t2    182  ",
+      " end_t3    273  ",
+      " end_t4    365  ")))
 
 ## Check summary method with events
 summary(run(model))
@@ -554,7 +557,7 @@ res <- assertError(SimInf_model(G     = G,
                                 ldata = matrix(rep(0, Nn), nrow = 1),
                                 tspan = as.numeric(1:10),
                                 u0    = u0))
-check_error(res, "U must be an integer.")
+check_error(res, "'U' must be an integer matrix.")
 
 ## Check U. Should not raise an error if U is an integer vector of length 0
 SimInf_model(G     = G,
@@ -571,7 +574,7 @@ res <- assertError(SimInf_model(G     = G,
                                 ldata = matrix(rep(0, Nn), nrow = 1),
                                 tspan = as.numeric(1:10),
                                 u0    = u0))
-check_error(res, "U must be equal to 0 x 0 matrix.")
+check_error(res, "'U' must be equal to a 0 x 0 matrix.")
 
 ## Check V. Change storage mode of V to double.
 ## Should not raise error
@@ -604,7 +607,7 @@ res <- assertError(SimInf_model(G     = G,
                                 ldata = matrix(rep(0, Nn), nrow = 1),
                                 tspan = as.numeric(1:10),
                                 u0    = u0))
-check_error(res, "V must be numeric.")
+check_error(res, "'V' must be a double matrix.")
 
 ## Check V. Should raise error if V is a vector of length > 0
 res <- assertError(SimInf_model(G     = G,
@@ -614,7 +617,7 @@ res <- assertError(SimInf_model(G     = G,
                                 ldata = matrix(rep(0, Nn), nrow = 1),
                                 tspan = as.numeric(1:10),
                                 u0    = u0))
-check_error(res, "V must be equal to 0 x 0 matrix.")
+check_error(res, "'V' must be equal to a 0 x 0 matrix.")
 
 ## Check V. Should not raise an error if V is an integer vector of length 0
 SimInf_model(G     = G,
@@ -709,23 +712,31 @@ res <- assertError(prevalence(result, I ~ S + I + R, node = 10))
 check_error(res, "'node' must be integer <= number of nodes.")
 
 ## Check 'gdata'
-model <- SIR(u0 = data.frame(S = 99, I = 1, R = 0),
-             tspan = 1:5, beta = 2, gamma = 4)
+model <- SISe(u0 = data.frame(S = 10, I = 0), tspan = 1:10, phi = 0,
+              upsilon = 1, gamma = 2, alpha = 3, beta_t1 = 4,
+              beta_t2 = 5, beta_t3 = 6, beta_t4 = 7, end_t1  = 91,
+              end_t2  = 182, end_t3  = 273, end_t4  = 365, epsilon = 8)
 
-stopifnot(identical(gdata(model), c(beta = 2, gamma = 4)))
-gdata(model, "beta") <- 6
-stopifnot(identical(gdata(model), c(beta = 6, gamma = 4)))
+stopifnot(identical(gdata(model),
+                    c(upsilon = 1, gamma = 2, alpha = 3, beta_t1 = 4,
+                      beta_t2 = 5, beta_t3 = 6, beta_t4 = 7, epsilon = 8)))
+
+gdata(model, "epsilon") <- 9
+
+stopifnot(identical(gdata(model),
+                    c(upsilon = 1, gamma = 2, alpha = 3, beta_t1 = 4,
+                      beta_t2 = 5, beta_t3 = 6, beta_t4 = 7, epsilon = 9)))
 
 res <- assertError(gdata(model) <- 6)
 check_error(res, "Missing 'parameter' argument.")
 
-res <- assertError(gdata(model, "beta") <- "6")
+res <- assertError(gdata(model, "epsilon") <- "6")
 check_error(res, "'value' argument must be a numeric.")
 
 res <- assertError(gdata(model, 5) <- 6)
 check_error(res, "'parameter' argument must be a character.")
 
-res <- assertError("gdata<-" (model, "beta"))
+res <- assertError("gdata<-" (model, "epsilon"))
 check_error(res, "Missing 'value' argument.")
 
 ## Check 'ldata'
